memorylimiterextension

package module
v0.151.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 28, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

README

Memory Limiter Extension

Status
Stability development
Distributions []
Issues Open issues Closed issues

The memory limiter extension is used to prevent out of memory situations on the collector. The extension will potentially replace the Memory Limiter Processor. It provides better guarantees from running out of memory as it will be used by the receivers to reject requests before converting them into OTLP. All the configurations are the same as Memory Limiter Processor.

This extension can be used as an extension for all HTTP and gRPC receivers that are configured through the standard confighttp and configgrpc libraries. For example, to configure this extension in the OTLP receiver:

receivers:
  otlp:
    protocols:
      grpc:
        middlewares:
          - id: memory_limiter
      http:
        middlewares:
          - id: memory_limiter

extensions:
  memory_limiter:
    check_interval: 1s
    limit_percentage: 1
    spike_limit_percentage: 0.05

see memorylimiterprocessor for additional details

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() extension.Factory

NewFactory returns a new factory for the Memory Limiter extension.

Types

type Config

type Config = memorylimiter.Config

Directories

Path Synopsis
internal
metadata
Package metadata contains the autogenerated telemetry and build information for the extension/memory_limiter component.
Package metadata contains the autogenerated telemetry and build information for the extension/memory_limiter component.

Jump to